@@ -502,10 +502,6 @@ class Builder(Update):
                 mask = mask.partition('=')[2].strip("\n")
                 yield (self.Id, mask, mask.replace('>=', '<'))
 
-    class AtiDriver(Driver):
-        Id = 'ati-drivers'
-        Package = 'x11-drivers/ati-drivers'
-
     def pretend_package_install(self, atom, chroot_path, logfile=None):
         """
         Получить список пакетов для установки
@@ -648,11 +644,11 @@ class Builder(Update):
         return True
 
     def create_video_data(self, builder_path, repository_data):
-        driver_list = list(chain(self.NvidiaDriver(builder_path),
-                                 self.AtiDriver(builder_path)))
+        driver_list = list(self.NvidiaDriver(builder_path))
         logfile = self._get_log_file()
         cache_file = self.clVars.Get('builder.cl_builder_video_driver_path')
         map_rep = dict(repository_data)
+        video_ebuilds = set()
         with writeFile(cache_file) as f:
             for drv_name, drv_mask, drv_atom in driver_list:
                 package_list = self.pretend_package_install(
@@ -678,7 +674,12 @@ class Builder(Update):
                             dn=map_rep[package['REPO']],
                             drv=drv_name,
                             mask=drv_mask.strip('"'))
+                        video_ebuilds.add(
+                            "%s/%s/%s"%(map_rep[package['REPO']],
+                                                  package['CATEGORY'],
+                                                  package['PN']))
                         f.write(s)
+        self.clVars.Set('cl_builder_video_ebuilds', list(video_ebuilds))
         return True
 
     def remove_video_drivers(self, builder_path):
